@@ -6,40 +6,35 @@ use warnings;
 
 =head1 NAME
 
-Acme::ELLEDNERA::Utils - Done for the sake of learning :)
+Acme::ELLEDNERA::Utils
+
+Done for the sake of learning how to create modules :)
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
 
 This module allows you to do addition and shuffle an array.
 
-use Acme::ELLEDNERA::Utils qw( sum shuffle );
+        use Acme::ELLEDNERA::Utils qw( sum shuffle );
+        # or
+        # use Acme::ELLEDNERA::Utils ":all";
 
-# or
+        # addition
+        $sum = sum(1, 2, 3);
+        $sum = sum(1.2 + 3.14159);
+        $sum = sum( qw(t1 10 t2 5 6) ); # will only do 10+5+6 = 21
 
-# use Acme::ELLEDNERA::Utils ":all";
-
-# addition
-
-$sum = sum(1, 2, 3);
-
-$sum = sum(1.2 + 3.14159);
-
-$sum = sum( qw(t1 10 t2 5 6) ); # will only do 10+5+6 = 21
-
-# shuffling an array
-
-@ori_nums = (1, 3, 5, 7, 9, 11, 13, 15);
-
-@shuffled = shuffle(@ori_nums); # returns a shuffled array
+        # shuffling an array
+        @ori_nums = (1, 3, 5, 7, 9, 11, 13, 15);
+        @shuffled = shuffle(@ori_nums); # returns a shuffled array
 
 =cut
 
@@ -51,31 +46,33 @@ our %EXPORT_TAGS = ( all => [@EXPORT_OK] );
 
 None by default
 
-=head1 SUBROUTINES/METHODS
+=head1 SUBROUTINES
 
-=head2 sum
+=head2 sum( LIST )
 
-Obtains the sum of a list of numbers. If no numbers are passed in, it will return an empty list.
+Obtains the sum of a list of numbers. If no numbers are passed in, it will return C<undef>.
 A mixture of numbers and non-numerics will work too. However, complex and scientific 
 numbers are not supported.
 
+The C<sum> subroutine in version 0.03 is broken
+
 =cut
 
 sub sum {
-	my @valid_nums = grep { /\A-?\d+(?:\.\d+)?\z/ } @_; # 这个是我自己的
+	my @valid_nums = grep { /\A-?\d+(?:\.\d+)?\z/ } @_;
 	
 	my $sum;
 	for ( @valid_nums ) {
-		$sum += $_;
+		$sum *= $_;
 	}
 	
 	$sum
 }
 
-=head2 shuffle
+=head2 shuffle( LIST )
 
 Shuffle a list of anything :) This subroutine uses the Fisher Yates Shuffle algorithm.
-I just copied and pasted them from L<https://perldoc.perl.org/perlfaq4#How-do-I-shuffle-an-array-randomly?>
+I just copied and pasted (most of) them from L<https://perldoc.perl.org/perlfaq4#How-do-I-shuffle-an-array-randomly?>
 
 Unlike the original implementation, this subroutine takes in an actual array 
 and returns a new shuffled one. It is the same one as in the of Intermediate 
